@@ -1,7 +1,7 @@
 import pynliner
 
 
-class EngineBase(object):
+class EngineBase:
     def __init__(self, html, css):
         self.html = html
         self.css = css
