@@ -1,7 +1,5 @@
 from django import template
-
-from django.utils.encoding import smart_text
-from django.contrib.staticfiles import finders
+from django.utils.encoding import smart_str
 
 from django_inlinecss import conf
 
@@ -15,15 +13,14 @@ class InlineCssNode(template.Node):
 
     def render(self, context):
         rendered_contents = self.nodelist.render(context)
-        css = ''
+        css = ""
         for expression in self.filter_expressions:
             path = expression.resolve(context, True)
             if path is not None:
-                path = smart_text(path)
-            expanded_path = finders.find(path)
+                path = smart_str(path)
 
-            with open(expanded_path) as css_file:
-                css = ''.join((css, css_file.read()))
+            css_loader = conf.get_css_loader()()
+            css = "".join((css, css_loader.load(path)))
 
         engine = conf.get_engine()(html=rendered_contents, css=css)
         return engine.render()
@@ -31,13 +28,11 @@ class InlineCssNode(template.Node):
 
 @register.tag
 def inlinecss(parser, token):
-    nodelist = parser.parse(('endinlinecss',))
+    nodelist = parser.parse(("endinlinecss",))
 
     # prevent second parsing of endinlinecss
     parser.delete_first_token()
 
     args = token.split_contents()[1:]
 
-    return InlineCssNode(
-        nodelist,
-        [parser.compile_filter(arg) for arg in args])
+    return InlineCssNode(nodelist, [parser.compile_filter(arg) for arg in args])
